@@ -33,7 +33,7 @@ class UploadTokenRequest(NamespacedResource):
         )
         self.pvc_name = pvc_name
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             self.res.update({"spec": {"pvcName": self.pvc_name}})
